==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ResourceQuotaStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceQuotaStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceQuotaStatusFluent<A>{
  public ResourceQuotaStatusFluentImpl() {
  }
  public ResourceQuotaStatusFluentImpl(io.fabric8.kubernetes.api.model.ResourceQuotaStatus instance) {
    this.withHard(instance.getHard()); 
    this.withUsed(instance.getUsed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> hard;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> used;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToHard(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.hard == null && key != null && value != null) { this.hard = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.hard.put(key, value);} return (A)this;
  }
  public A addToHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.hard == null && map != null) { this.hard = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.hard.putAll(map);} return (A)this;
  }
  public A removeFromHard(java.lang.String key) {
    if(this.hard == null) { return (A) this; }
    if(key != null && this.hard != null) {this.hard.remove(key);} return (A)this;
  }
  public A removeFromHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.hard == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.hard != null){this.hard.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getHard() {
    return this.hard;
  }
  public <K,V>A withHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> hard) {
    if (hard == null) { this.hard =  null;} else {this.hard = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(hard);} return (A) this;
  }
  public java.lang.Boolean hasHard() {
    return this.hard != null;
  }
  public A addToUsed(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.used == null && key != null && value != null) { this.used = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(key != null && value != null) {this.used.put(key, value);} return (A)this;
  }
  public A addToUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.used == null && map != null) { this.used = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(); }
    if(map != null) { this.used.putAll(map);} return (A)this;
  }
  public A removeFromUsed(java.lang.String key) {
    if(this.used == null) { return (A) this; }
    if(key != null && this.used != null) {this.used.remove(key);} return (A)this;
  }
  public A removeFromUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.used == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.used != null){this.used.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsed() {
    return this.used;
  }
  public <K,V>A withUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> used) {
    if (used == null) { this.used =  null;} else {this.used = new java.util.LinkedHashMap<java.lang.String,io.fabric8.kubernetes.api.model.Quantity>(used);} return (A) this;
  }
  public java.lang.Boolean hasUsed() {
    return this.used != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceQuotaStatusFluentImpl that = (ResourceQuotaStatusFluentImpl) o;
    if (hard != null ? !hard.equals(that.hard) :that.hard != null) return false;
    if (used != null ? !used.equals(that.used) :that.used != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hard,  used,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/ResourceQuotaStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ResourceQuotaStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.ResourceQuotaStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.ResourceQuotaStatusFluent<A>{
  public ResourceQuotaStatusFluentImpl() {
  }
  public ResourceQuotaStatusFluentImpl(io.fabric8.kubernetes.api.model.ResourceQuotaStatus instance) {
    this.withHard(instance.getHard()); 
    this.withUsed(instance.getUsed()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> hard;
  private java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> used;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToHard(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.hard == null && key != null && value != null) { this.hard = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.hard.put(key, value);} return (A)this;
  }
  public A addToHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.hard == null && map != null) { this.hard = new java.util.LinkedHashMap(); }
    if(map != null) { this.hard.putAll(map);} return (A)this;
  }
  public A removeFromHard(java.lang.String key) {
    if(this.hard == null) { return (A) this; }
    if(key != null && this.hard != null) {this.hard.remove(key);} return (A)this;
  }
  public A removeFromHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.hard == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.hard != null){this.hard.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getHard() {
    return this.hard;
  }
  public <K,V>A withHard(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> hard) {
    if (hard == null) { this.hard =  null;} else {this.hard = new java.util.LinkedHashMap(hard);} return (A) this;
  }
  public java.lang.Boolean hasHard() {
    return this.hard != null;
  }
  public A addToUsed(java.lang.String key,io.fabric8.kubernetes.api.model.Quantity value) {
    if(this.used == null && key != null && value != null) { this.used = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.used.put(key, value);} return (A)this;
  }
  public A addToUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.used == null && map != null) { this.used = new java.util.LinkedHashMap(); }
    if(map != null) { this.used.putAll(map);} return (A)this;
  }
  public A removeFromUsed(java.lang.String key) {
    if(this.used == null) { return (A) this; }
    if(key != null && this.used != null) {this.used.remove(key);} return (A)this;
  }
  public A removeFromUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> map) {
    if(this.used == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.used != null){this.used.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> getUsed() {
    return this.used;
  }
  public <K,V>A withUsed(java.util.Map<java.lang.String,io.fabric8.kubernetes.api.model.Quantity> used) {
    if (used == null) { this.used =  null;} else {this.used = new java.util.LinkedHashMap(used);} return (A) this;
  }
  public java.lang.Boolean hasUsed() {
    return this.used != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ResourceQuotaStatusFluentImpl that = (ResourceQuotaStatusFluentImpl) o;
    if (hard != null ? !hard.equals(that.hard) :that.hard != null) return false;
    if (used != null ? !used.equals(that.used) :that.used != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(hard,  used,  additionalProperties,  super.hashCode());
  }
  
}
